@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class CreateAudioDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param FileName: 对应数据Base64文件名称
@@ -66,7 +66,7 @@ class CreateAudioDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -76,7 +76,7 @@ class CreateAudioDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -94,13 +94,6 @@ class CreateAudioDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateDataDepositRequest(AbstractModel):
@@ -109,7 +102,7 @@ class CreateDataDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceInfo: 业务数据明文(json格式字符串)，最大256kb
         :type EvidenceInfo: str
         :param EvidenceName: 存证名称(长度最大30)
@@ -143,7 +136,7 @@ class CreateDataDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -153,7 +146,7 @@ class CreateDataDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -171,13 +164,6 @@ class CreateDataDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateDocDepositRequest(AbstractModel):
@@ -186,7 +172,7 @@ class CreateDocDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param FileName: 对应数据Base64文件名称
@@ -228,7 +214,7 @@ class CreateDocDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -238,7 +224,7 @@ class CreateDocDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -256,13 +242,6 @@ class CreateDocDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateHashDepositNoCertRequest(AbstractModel):
@@ -271,7 +250,7 @@ class CreateHashDepositNoCertRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceHash: 数据hash
         :type EvidenceHash: str
         :param BusinessId: 该字段为透传字段，方便调用方做业务处理， 长度最大不超过64
@@ -297,7 +276,7 @@ class CreateHashDepositNoCertRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -307,7 +286,7 @@ class CreateHashDepositNoCertResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 透传字段
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -337,13 +316,6 @@ class CreateHashDepositNoCertResponse(AbstractModel):
         self.EvidenceTxHash = params.get("EvidenceTxHash")
         self.BlockchainHeight = params.get("BlockchainHeight")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateHashDepositNoSealRequest(AbstractModel):
@@ -352,7 +324,7 @@ class CreateHashDepositNoSealRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceHash: 数据hash
         :type EvidenceHash: str
         :param BusinessId: 该字段为透传字段，方便调用方做业务处理， 长度最大不超过64
@@ -378,7 +350,7 @@ class CreateHashDepositNoSealRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -388,7 +360,7 @@ class CreateHashDepositNoSealResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 透传字段
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -418,13 +390,6 @@ class CreateHashDepositNoSealResponse(AbstractModel):
         self.EvidenceTxHash = params.get("EvidenceTxHash")
         self.BlockchainHeight = params.get("BlockchainHeight")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateHashDepositRequest(AbstractModel):
@@ -433,7 +398,7 @@ class CreateHashDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param EvidenceHash: 数据hash
@@ -463,7 +428,7 @@ class CreateHashDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -473,7 +438,7 @@ class CreateHashDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 透传字段
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -491,13 +456,6 @@ class CreateHashDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateImageDepositRequest(AbstractModel):
@@ -506,7 +464,7 @@ class CreateImageDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param FileName: 对应数据Base64文件名称 test.png
@@ -548,7 +506,7 @@ class CreateImageDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -558,7 +516,7 @@ class CreateImageDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -576,13 +534,6 @@ class CreateImageDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateVideoDepositRequest(AbstractModel):
@@ -591,7 +542,7 @@ class CreateVideoDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param FileName: 对应数据Base64文件名称
@@ -633,7 +584,7 @@ class CreateVideoDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -643,7 +594,7 @@ class CreateVideoDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -661,13 +612,6 @@ class CreateVideoDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateWebpageDepositRequest(AbstractModel):
@@ -676,7 +620,7 @@ class CreateWebpageDepositRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceName: 存证名称(长度最大30)
         :type EvidenceName: str
         :param EvidenceUrl: 网页链接
@@ -706,7 +650,7 @@ class CreateWebpageDepositRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -716,7 +660,7 @@ class CreateWebpageDepositResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BusinessId: 业务ID 透传 长度最大不超过64
 注意：此字段可能返回 null，表示取不到有效值。
         :type BusinessId: str
@@ -734,13 +678,6 @@ class CreateWebpageDepositResponse(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.EvidenceId = params.get("EvidenceId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class GetDepositCertRequest(AbstractModel):
@@ -749,7 +686,7 @@ class GetDepositCertRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编码
         :type EvidenceId: str
         """
@@ -763,7 +700,7 @@ class GetDepositCertRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -773,7 +710,7 @@ class GetDepositCertResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编码
         :type EvidenceId: str
         :param EvidenceCert: 存证证书文件临时链接
@@ -790,13 +727,6 @@ class GetDepositCertResponse(AbstractModel):
         self.EvidenceId = params.get("EvidenceId")
         self.EvidenceCert = params.get("EvidenceCert")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class GetDepositFileRequest(AbstractModel):
@@ -805,7 +735,7 @@ class GetDepositFileRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编码
         :type EvidenceId: str
         """
@@ -819,7 +749,7 @@ class GetDepositFileRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -829,7 +759,7 @@ class GetDepositFileResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编号
         :type EvidenceId: str
         :param EvidenceFile: 存证文件临时链接
@@ -846,13 +776,6 @@ class GetDepositFileResponse(AbstractModel):
         self.EvidenceId = params.get("EvidenceId")
         self.EvidenceFile = params.get("EvidenceFile")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class GetDepositInfoRequest(AbstractModel):
@@ -861,7 +784,7 @@ class GetDepositInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编码
         :type EvidenceId: str
         """
@@ -875,7 +798,7 @@ class GetDepositInfoRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -885,7 +808,7 @@ class GetDepositInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvidenceId: 存证编号
         :type EvidenceId: str
         :param EvidenceTime: 上链时间
@@ -909,11 +832,4 @@ class GetDepositInfoResponse(AbstractModel):
         self.EvidenceTime = params.get("EvidenceTime")
         self.EvidenceTxHash = params.get("EvidenceTxHash")
         self.BlockchainHeight = params.get("BlockchainHeight")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
